@@ -1,6 +1,6 @@
 package Statocles::App::Plain;
 # ABSTRACT: Plain documents made into pages with no extras
-$Statocles::App::Plain::VERSION = '0.031';
+$Statocles::App::Plain::VERSION = '0.032';
 use Statocles::Base 'Class';
 extends 'Statocles::App';
 use List::Util qw( first );
@@ -22,14 +22,6 @@ has store => (
 );
 
 
-has theme => (
-    is => 'ro',
-    isa => Theme,
-    required => 1,
-    coerce => Theme->coercion,
-);
-
-
 sub pages {
     my ( $self ) = @_;
     my @pages;
@@ -41,7 +33,7 @@ sub pages {
         my $page = Statocles::Page::Document->new(
             path => join( '/', $self->url_root, $url ),
             document => $doc,
-            layout => $self->theme->template( site => 'layout.html' ),
+            layout => $self->site->theme->template( site => 'layout.html' ),
             published => Time::Piece->new,
         );
 
@@ -68,14 +60,13 @@ Statocles::App::Plain - Plain documents made into pages with no extras
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 SYNOPSIS
 
     my $app = Statocles::App::Plain->new(
         url_root => '/',
         store => 'share/root',
-        theme => 'share/theme/default',
     );
     my @pages = $app->pages;
 
@@ -94,12 +85,6 @@ The root URL for this application. Required.
 
 The L<store|Statocles::Store> containing this app's documents. Required.
 
-=head2 theme
-
-The L<theme|Statocles::Theme> for this app. Required.
-
-Only layouts are used.
-
 =head1 METHODS
 
 =head2 pages
@@ -112,7 +97,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Doug Bell.
+This software is copyright (c) 2015 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
